--- loncom/xml/lontexconvert.pm 2011/02/10 19:28:29 1.105
+++ loncom/xml/lontexconvert.pm 2011/05/27 18:34:07 1.107
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# TeX Conversion Module
#
-# $Id: lontexconvert.pm,v 1.105 2011/02/10 19:28:29 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.107 2011/05/27 18:34:07 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -165,10 +165,12 @@ sub clean_out_math_mode {
sub displaystyle {
my ($texstring)=@_;
#has a $$ or \[ or \displaystyle in it, guessinng it's display mode
if ($$texstring=~/[^\\]\$\$/ ||
- $$texstring=~/\\\[/ ||
- $$texstring=~/\\displaystyle/) { return 1; }
+ $$texstring=~/\\\[/ ||
+ $$texstring=~/\\displaystyle/ ||
+ $$texstring=~/eqnarray/
+ ) { return 1; }
return 0;
}
@@ -250,9 +252,9 @@ sub mimetex_valign {
my $path = '/cgi-bin/mimetex.cgi?'.$esc_texstring;
my $socket;
&Apache::lonxml::start_alarm();
- my $socket = IO::Socket::INET->new(PeerAddr => $hostname,
- PeerPort => 'http(80)',
- Proto => 'tcp');
+ $socket = IO::Socket::INET->new(PeerAddr => $hostname,
+ PeerPort => 'http(80)',
+ Proto => 'tcp');
if ($socket) {
my $headreq = "HEAD $path HTTP/1.0\r\n\r\n";
print $socket $headreq;
@@ -289,7 +291,7 @@ sub mimetex_converted {
my $valign = &mimetex_valign($esc_texstring);
my $result='';
if ($displaystyle) {
- $result='
@@ -165,10 +165,12 @@ sub clean_out_math_mode {
sub displaystyle {
my ($texstring)=@_;
- #has a $$ or \[ or \displaystyle in it, guessinng it's display mode
+ #has a $$ or \[ or \displaystyle or eqnarray in it, guessinng it's display mode
if ($$texstring=~/[^\\]\$\$/ ||